function [r_post_burn,r_post_inf,r_inf,details]=main(Y,X,n_burn,n_times,n_inference,sampling,seed)

% This set of routines implements the linear regression model with skew-IStudent errors introduced in
% the article below, that must be referred to if the routines are used.
%
% Ferreira, JTAS and Steel, MJF (2003) Bayesian Multivariate Regression Analysis 
% with a New Class of Skewed Distributions. University of Kent Technical Report.
%
% Input parameters:
%
%   Y - variable of interest, each row denotes an observation
%   X - covariates, each row for the corresponding row of Y
%   n_burn - no. of burn-in iterations
%   n_times - no. of updates in the burn-in phase (used to set the variance of the M-H samplers)
%   n_inference - no. of iterations during burn in phase
%   sampling - collect every sampling-th iterations
%   seed - seed for the random no generator
%
% Output parameters
%
%   r_post_burn - loglikelihood (1st column) and logprior (up to a constant) evolution during burn-in phase 
%   r_post_inf - likelihood (1st column) and prior
%   r_inf - samples from the posterior. Each row from each of the objects denotes a sample
%   details - time spend during burn-in and inference phases
%
% J T A S Ferreira and M F J Steel  03/07/2003

if nargin <6
    error('At least 6 parameters need to be defined')
end

if nargin==6
    seed=0;
end

rand('state',seed)

%clearing global variables

clear global
warning off
global X Y n m k loglik logprior theta O U B gamm G v lambda pg_0 d_0 v0 YXB
warning on

if nargin<5
    error('Unappropriate number of parameters')
end
    
[n,m]=size(Y);
k = size(X,2);
n_angles=m*(m-1)/2;

% Initial parameters
U=eye(m);
theta=[linspace(.3,.5,m-1)]'*ones(1,m-1);
[O]=detO(theta,m);
B=zeros(k,m);
gamm=ones(m,1);
G=ones(n,1)*gamm';
lambda=ones(n,m);
v=ones(m,1)*1000;

% Prior parameters
pg_0=1;        % prior on gamma
d_0=.1;         % prior on \nu
v0=3;

% p(B,Sigma) propto |Sigma|^((m+1)/2)

% Likelihood and prior
[loglik]=detloglik(O*U,B,gamm,G,lambda,Y,X,n,m);
[logprior]=detlogprior(theta,U,B,gamm,v,n,m,k,pg_0,d_0);

%Burn - in
tic
[r_post_burn,s]=burn(n_burn,n_times);
details.t_burn=toc;

%Inference
tic
[r_post_inf,r_inf]=inference(n_inference,sampling,s);
details.t_inf=toc;

clear global